// Tab.hh for Fluxbox
// Copyright (c) 2001 Henrik Kinnunen (fluxgen@linuxmail.org)
//
// Permission is hereby granted, free of charge, to any person obtaining a
// copy of this software and associated documentation files (the "Software"),
// to deal in the Software without restriction, including without limitation
// the rights to use, copy, modify, merge, publish, distribute, sublicense,
// and/or sell copies of the Software, and to permit persons to whom the
// Software is furnished to do so, subject to the following conditions:
//
// The above copyright notice and this permission notice shall be included in
// all copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.  IN NO EVENT SHALL
// THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
// FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
// DEALINGS IN THE SOFTWARE.

#ifndef __TAB_HH__
#define __TAB_HH__
#include "Window.hh"
#include "Screen.hh"


class Tab {
public:
	Tab(BlackboxWindow *win, Tab *prev=0, Tab *next=0);
	~Tab();
	void draw(bool pressed);
	inline Tab *next() const { return m_next; }
	inline Tab *prev() const { return m_prev; }
	inline BlackboxWindow *getWindow() const { return m_win; }
	void raise();
	//position tab to follow m_win (BlackboxWindow *)
	void setPosition();
	//event handlers
	void buttonReleaseEvent(XButtonEvent *be);
	void buttonPressEvent(XButtonEvent *be);
	void exposeEvent(XExposeEvent *ee);	
private:
	static unsigned int size_w;
	static unsigned int size_h;
	bool m_focus;
	void createTabWindow();
	Tab *m_prev;
	Tab *m_next;
	BlackboxWindow *m_win;
	Window m_tabwin;
	Display *m_display;
};

#endif //__TAB_HH__
